Declarative Base
================

.. automodule:: stonesoup.base
    :no-members:

.. autoclass:: stonesoup.base.Property
    :no-members:
.. autoclass:: stonesoup.base.BaseMeta
.. autoclass:: stonesoup.base.Base


